@@ -116,7 +116,7 @@ def run(args):
                                    'validated_jobs', 'validated_payloads', 'monitored_payloads',
                                    'finished_jobs', 'finished_payloads', 'finished_data_in', 'finished_data_out',
                                    'failed_jobs', 'failed_payloads', 'failed_data_in', 'failed_data_out',
-                                   'completed_jobs', 'completed_jobids'])
+                                   'completed_jobs', 'completed_jobids'])  #, 'interceptor_messages'])
 
     queues.jobs = queue.Queue()
     queues.payloads = queue.Queue()
@@ -141,6 +141,8 @@ def run(args):
     queues.completed_jobs = queue.Queue()
     queues.completed_jobids = queue.Queue()
 
+    # queues.interceptor_messages = queue.Queue()
+
     logger.info('setting up tracing')
     traces = namedtuple('traces', ['pilot'])
     traces.pilot = {'state': SUCCESS,
